@@ -66,10 +66,12 @@ def login():
     referrer = request.referrer
     target_service = "{}{}/login".format(referrer, environment)
     if not ticket:
-        route_to_request_ticket = "{}?service={}".format(CAS_LOGIN_URL, target_service)
+        route_to_request_ticket = "{}?service={}".format(CAS_LOGIN_URL, target_service)        
+        app.logger.info(route_to_request_ticket)
         return redirect(route_to_request_ticket)
     environment = environment if environment is not None else "autosubmitapp" # can be used to target the test environment    
     cas_verify_ticket_route = CAS_VERIFY_URL + '?service=' + target_service + '&ticket=' + ticket
+    app.logger.info(cas_verify_ticket_route)    
     response = requests.get(cas_verify_ticket_route)
     user = None
     if response:
